pub struct State { /* private fields */ }
The state of Ascon’s permutation.
The permutation operates on a state of 320 bits represented as 5 64 bit words.
Instantiate new state from the given values.
Perform permutation with 12 rounds.
Perform permutation with 8 rounds.
Perform permutation with 6 rounds.
Perform permutation with 1 round
Perform a given number (up to 12) of permutations
Panics (in debug mode) if rounds is larger than 12.
Converts this type into a shared reference of the (usually inferred) input type.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Converts to this type from the input type.
Converts to this type from the input type.
The returned type after indexing.
Performs the indexing (
container[index]) operation.
Read more
Performs the mutable indexing (
container[index]) operation.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.